@@ -199,8 +199,11 @@ class GeoArray(object):
                                 "Received %s." % type(list_bandnames))
             if len(list_bandnames) != self.bands:
                 raise ValueError('Number of given bandnames does not match number of bands in array.')
-            if len(list(set([type(b) for b in list_bandnames]))) != 1 or not isinstance(list_bandnames[0], str):
-                raise ValueError("'bandnames must be a set of strings. Got other datatypes in there.'")
+            if len(list(set([type(b) for b in list_bandnames]))) != 1:
+                raise ValueError('Multiple data types of the band names are not supported.')
+            if not isinstance(list_bandnames[0], (str, int, float)):
+                raise ValueError(f'Band names must be a set of strings, integers, or floats. '
+                                 f'Got {type(list_bandnames[0])}')
 
             bN_dict = OrderedDict((band, i) for i, band in enumerate(list_bandnames))
 
@@ -1054,7 +1057,7 @@ class GeoArray(object):
                     band = ds_out.GetRasterBand(bidx + 1)
 
                     if 'band_names' in envi_metadict:
-                        bandname = self.metadata.band_meta['band_names'][bidx].strip()
+                        bandname = str(self.metadata.band_meta['band_names'][bidx]).strip()
                         band.SetDescription(bandname)
                         assert band.GetDescription() == bandname
 
@@ -1113,7 +1116,8 @@ class GeoArray(object):
                         # meta2write = dict((k, repr(v)) for k, v in self.metadata.band_meta.items() if v is not np.nan)
 
                         if 'band_names' in bandmeta:
-                            band.SetDescription(self.metadata.band_meta['band_names'][bidx].strip())
+                            bandname = str(self.metadata.band_meta['band_names'][bidx]).strip()
+                            band.SetDescription(bandname)
                             del bandmeta['band_names']
 
                         if 'nodata' in bandmeta:
